
class NoMessageError(Exception):
    """
    No message was returned when consuming from the broker
    """
    pass

class NetworkError(Exception):
    """
    Generic network errors
    """
    pass

class ConsumeMessageError(Exception):
    """
    Non-trivial errors when consuming from the broker
    """
    pass

class MessageValueException(Exception):
    """
    Represents a significant error in the value of the message
    """
    pass



import sys
import logging
import os


def _init_handler():
    handler = logging.StreamHandler(sys.stdout)
    handler.setLevel(_get_loglevel())

    handler.setFormatter(
        logging.Formatter(
            "{process} - {filename:15} - {asctime} - {name} - {levelname} - {message}",
            style="{"
        )
    )
    return handler


def _get_loglevel():
    return os.environ.get('LOGLEVEL', 'CRITICAL')


def init_logger():
    logger = logging.getLogger()
    logger.name = 'nubium-utils'
    logger.setLevel(_get_loglevel())
    logger.addHandler(_init_handler())




def success_headers(headers):
    """
    Updates headers for a message when a process succeeds

    Resets the kafka_retry_count to 0,
    or adds if it didn't originally exist
    """
    headers = dict(headers)
    headers['kafka_retry_count'] = '0'
    return headers



from .consumer_utils import consume_message, get_message_headers
from .message_utils import success_headers
from .retry_logic import produce_retry_message
from .logging_utils import init_logger

init_logger()



import os


def produce_retry_message(message, producer, error):
    """
    Produces a message to the correct retry topic with an updated header

    The message header should contain a `kafka_retry_count` field,
    which is an integer representation of how many times the message has
    been tried for the current topic.
    If greater than the allowed maximum, produces to the retry topic.
    If less than the allowed maximum, produces to the current topic.
    """

    message_headers = dict(message.headers())
    kafka_retry_count = int(message_headers['kafka_retry_count'])

    # If less than the retry max, produce onto the retry topic
    if kafka_retry_count < int(os.environ['RETRY_COUNT_MAX']):
        message_headers['kafka_retry_count'] = str(kafka_retry_count + 1)
        producer.produce(
            topic=os.environ['CONSUME_TOPICS'],
            value=message.value(),
            key=message.key(),
            headers=message_headers
        )

    # Otherwise, reset the retry count and produce to the fail topic
    else:
        message_headers['kafka_retry_count'] = '0'
        producer.produce(
            topic=os.environ['PRODUCE_RETRY_TOPICS'],
            value=message.value(),
            key=message.key(),
            headers=message_headers
        )
